@@ -202,7 +202,7 @@ fn assert_expand(
 
     let arg_tts = args.into_iter().flat_map(|arg| {
         quote! { &(#arg), }
-    }.token_trees).collect::<Vec<_>>();
+    }.token_trees);
 
     let expanded = quote! {
         { { (##arg_tts); } }
@@ -254,9 +254,15 @@ fn format_args_expand(
     let _format_string = args.remove(0);
     let arg_tts = args.into_iter().flat_map(|arg| {
         quote! { std::fmt::ArgumentV1::new(&(#arg), std::fmt::Display::fmt), }
-    }.token_trees).collect::<Vec<_>>();
+    }.token_trees);
     let expanded = quote! {
-        std::fmt::Arguments::new_v1(&[], &[##arg_tts])
+        // It's unsafe since https://github.com/rust-lang/rust/pull/83302
+        // Wrap an unsafe block to avoid false-positive `missing-unsafe` lint.
+        // FIXME: Currently we don't have `unused_unsafe` lint so an extra unsafe block won't cause issues on early
+        // stable rust-src.
+        unsafe {
+            std::fmt::Arguments::new_v1(&[], &[##arg_tts])
+        }
     };
     ExpandResult::ok(expanded)
 }
@@ -420,7 +426,7 @@ fn parse_string(tt: &tt::Subtree) -> Result<String, mbe::ExpandError> {
             tt::TokenTree::Leaf(tt::Leaf::Literal(it)) => unquote_str(it),
             _ => None,
         })
-        .ok_or_else(|| mbe::ExpandError::ConversionError)
+        .ok_or(mbe::ExpandError::ConversionError)
 }
 
 fn include_expand(
@@ -432,9 +438,8 @@ fn include_expand(
         let path = parse_string(tt)?;
         let file_id = relative_file(db, arg_id, &path, false)?;
 
-        let subtree = parse_to_token_tree(&db.file_text(file_id))
-            .ok_or_else(|| mbe::ExpandError::ConversionError)?
-            .0;
+        let subtree =
+            parse_to_token_tree(&db.file_text(file_id)).ok_or(mbe::ExpandError::ConversionError)?.0;
         Ok((subtree, file_id))
     })();
 
@@ -611,7 +616,7 @@ mod tests {
 
                 let fragment = crate::to_fragment_kind(&macro_call);
                 let args = macro_call.token_tree().unwrap();
-                let parsed_args = mbe::ast_to_token_tree(&args).0;
+                let parsed_args = mbe::syntax_node_to_token_tree(args.syntax()).0;
                 let call_id = AstId::new(file_id.into(), ast_id_map.ast_id(&macro_call));
 
                 let arg_id = db.intern_macro(MacroCallLoc {
@@ -763,7 +768,7 @@ mod tests {
             format_args!("{} {:?}", arg1(a, b, c), arg2);
             "#,
             expect![[
-                r#"std::fmt::Arguments::new_v1(&[], &[std::fmt::ArgumentV1::new(&(arg1(a,b,c)),std::fmt::Display::fmt),std::fmt::ArgumentV1::new(&(arg2),std::fmt::Display::fmt),])"#
+                r#"unsafe{std::fmt::Arguments::new_v1(&[], &[std::fmt::ArgumentV1::new(&(arg1(a,b,c)),std::fmt::Display::fmt),std::fmt::ArgumentV1::new(&(arg2),std::fmt::Display::fmt),])}"#
             ]],
         );
     }
@@ -780,7 +785,7 @@ mod tests {
             format_args!("{} {:?}", a::<A,B>(), b);
             "#,
             expect![[
-                r#"std::fmt::Arguments::new_v1(&[], &[std::fmt::ArgumentV1::new(&(a::<A,B>()),std::fmt::Display::fmt),std::fmt::ArgumentV1::new(&(b),std::fmt::Display::fmt),])"#
+                r#"unsafe{std::fmt::Arguments::new_v1(&[], &[std::fmt::ArgumentV1::new(&(a::<A,B>()),std::fmt::Display::fmt),std::fmt::ArgumentV1::new(&(b),std::fmt::Display::fmt),])}"#
             ]],
         );
     }
